@@ -1471,6 +1471,61 @@ class AccessionLongReadRna(AccessionGenericRna):
         )
 
 
+class AccessionDnaseStarchFromBam(Accession):
+    """
+    See PROD-309. This is strictly meant for backfilling starch files into previously
+    accessioned runs.
+    """
+
+    QC_MAP: Dict[str, str] = {}
+
+    @property
+    def assembly(self) -> str:
+        filekey = "hotspot2_tar_gz"
+        return self.find_portal_property_from_filekey(filekey, EncodeFile.ASSEMBLY)
+
+    def post_analysis(self) -> EncodeGenericObject:
+        """
+        For these hacky runs we need to patch into the existing Analysis objects.
+        """
+        document_aliases = [
+            f"{self.common_metadata.lab_pi}:cromwell-metadata-{self.analysis.workflow_id}"
+        ]
+        document_attachment = self.analysis.metadata.get_as_attachment(
+            filename_prefix=self.experiment.accession
+        )
+        document = EncodeDocument(
+            attachment=document_attachment,
+            common_metadata=self.common_metadata,
+            document_type=EncodeDocumentType.WorkflowMetadata,
+            aliases=document_aliases,
+        )
+        posted_document = self.post_document(document)
+        payload = {
+            self.conn.PROFILE_KEY: "analysis",
+            self.conn.ENCID_KEY: self.analysis.metadata.content["inputs"]["replicates"][
+                0
+            ]["analysis"],
+            "files": [f.at_id for f in self.new_files],
+            "documents": [posted_document.at_id],
+        }
+
+        response = self.conn.patch(payload, extend_array_values=True)
+        modeled_analysis = EncodeGenericObject(response)
+        return modeled_analysis
+
+    def get_or_make_step_run(self, accession_step: AccessionStep) -> EncodeStepRun:
+        """
+        For the hacky runs we need to reuse the existing step runs.
+        """
+        return EncodeStepRun(
+            self.conn.get(
+                self.analysis.metadata.content["inputs"]["replicates"][0]["step_run"],
+                frame="object",
+            )
+        )
+
+
 class AccessionMicroRna(AccessionGenericRna):
     QC_MAP = {
         "mirna_mapping": "make_microrna_mapping_qc",
@@ -2224,9 +2279,6 @@ class AccessionWgbs(Accession):
                 for k, v in gembs_qc.items()
                 if k
                 not in (
-                    "correct_pairs",
-                    "general_reads",
-                    "pct_general_reads",
                     "pct_reads_in_control_sequences",
                     "pct_sequenced_reads",
                     "reads_in_control_sequences",
@@ -2249,13 +2301,7 @@ class AccessionWgbs(Accession):
             gs_file.task, "calculate_average_coverage", "average_coverage_qc"
         )[0]
         average_coverage_qc = self.backend.read_json(average_coverage_qc_file)
-        attachment_qc = {**average_coverage_qc, **gembs_qc}
-        qc_bytes = EncodeAttachment.get_bytes_from_dict(attachment_qc)
-        modeled_attachment = EncodeAttachment(qc_bytes, gs_file.filename)
-        attachment = modeled_attachment.get_portal_object(
-            mime_type="application/json", additional_extension=".json"
-        )
-        output_qc["attachment"] = attachment
+        output_qc.update(average_coverage_qc["average_coverage"])
         for k, v in output_qc.items():
             if k.startswith("pct"):
                 output_qc[k] = 100 * v
@@ -2337,6 +2383,7 @@ def accession_factory(
         "control_chip": AccessionChip,
         "atac": AccessionAtac,
         "dnase": AccessionDnase,
+        "dnase_starch_from_bam": AccessionDnaseStarchFromBam,
         "wgbs": AccessionWgbs,
     }
     selected_accession: Optional[Type[Accession]] = None
